"""
This module implements a portal-managed Image class.  It is based on
Zope's built-in Image object.
"""

from Globals import HTMLFile, HTML
from Products.PTKBase.PortalContent import PortalContent
from Discussions import Discussable
from Acquisition import Implicit
import Globals
import string

import Products.ExtFile.ExtImage

def addExtImage(self, file, title='', description='', 
    maxx='', maxy='', ratio=0, content_type='', REQUEST=None):
    """
    Add an Image
    """

    self=self.this()  # Why?

    # Instantiate the object and set its description.
    # The description is not set by the constructor because I didn't
    # want to extend Image's constructor.  Perhaps I should.
    filename=REQUEST['file'].filename
    id=''
        # generate id from filename
    if (filename) and (type(file) is not type('')):
        id=filename[max(string.rfind(filename,'/'), string.rfind(filename,'\\'), string.rfind(filename,':'))+1:]
    if id:
        id=string.replace(id,' ','_')   # make sure, there are no spaces in the id
        tempExtFile=ExtImage(id, REQUEST, title, description, file, content_type, maxx, maxy, ratio)
        tempExtFile.description=tempExtFile.descr
    
        # Add the File instance to self
        self._setObject(id, tempExtFile)

    if REQUEST is not None:
        REQUEST.RESPONSE.redirect(self.absolute_url()+'/portal_contents')
    
class ExtImage(Products.ExtFile.ExtImage.ExtImage, PortalContent, Discussable):
    """
    A Portal-managed Image
    """

    # The order of base classes is very significant in this case.
    # Image.Image does not store it's id in it's 'id' attribute.
    # Rather, it has an 'id' method which returns the contents of the
    # instnace's __name__ attribute.  Inheriting in the other order
    # obscures this method, resulting in much pulling of hair and
    # gnashing of teeth and fraying of nerves.  Don't do it.
    #
    # Really.
    
    meta_type='Portal ExtImage'

    __ac_permissions__ = (
        ('Change Portal Images', ('edit',), ('Owner',)),
        ('View management screens',('editForm',)),
        )
    
    def SearchableText(self):
        """
        SeachableText is used for full text seraches of a portal.  It
        should return a concatanation of all useful text.
        """
        return "%s %s" % (self.title, self.description)

    def toolbox_actions(self, url=0):
        if url==0: url=self.absolute_url()
        return (
            {'name':'View statistics',
             'url':  url + '/extImageStats',
             'permissions':('View',),
             'category':'object',
             },  
            {'name':'Edit',
             'url':  url + '/editForm',
             'permissions':('Change Portal Images',),
             'category':'object',
             },
            {'name':'View preview',
             'url':  url + '/ptk_preview',
             'permissions':('View',),
             'category':'object',
             },
            )


    def manage_afterAdd(self, item, container):
        """Both of my parents have an afterAdd method"""
        Products.ExtFile.ExtImage.ExtImage.manage_afterAdd(self, item, container)
        PortalContent.manage_afterAdd(self, item, container)

    def manage_beforeDelete(self, item, container):
        """Both of my parents have a beforeDelete method"""
        PortalContent.manage_beforeDelete(self, item, container)
        Products.ExtFile.ExtImage.ExtImage.manage_beforeDelete(self, item, container)
        

    def edit(self, title, description, content_type,
             precondition='', file='', REQUEST=None):
        """
        Perform changes for user
        """
        self.title = title
        self.descr = self.description = description
        self.content_type = content_type

        if file:
            self.manage_file_upload(file)

        # Tell the portal I changed
        self.getPortal().notify_content(
            self, self.getPortal().getAuthenticatedMember())
        
        if REQUEST is not None:
            return self.editForm(self, REQUEST,
                                 portal_status_message='Image changed.')

    editForm = HTMLFile('dtml/imageEdit', globals())

    view = HTMLFile('dtml/extImageView', globals())
    
    ptk_preview = HTMLFile('dtml/extImagePreview', globals())
    
    extImageStats = HTMLFile('dtml/extImageStats', globals())
    
    def index_html(self, REQUEST, RESPONSE):
        """
        Display the image, with our without standard_html_[header|footer],
        as appropreate.
        """
        if REQUEST['PATH_INFO'][-10:] == 'index_html':
            return self.view(self, REQUEST)
        return Products.ExtFile.ExtImage.ExtImage.index_html(self, REQUEST, RESPONSE)

Globals.default__class_init__( ExtImage )


from Products.PTKBase.register import registerPortalContent

registerPortalContent( ExtImage
                     , constructors=( addExtImage, )
                     , action='Wizards/ExtImage'
                     , icon=Globals.ImageFile( "extimage.gif", globals() )
                     )
